@@ -4,7 +4,8 @@ use warnings;
 
 package Dancer2::Session::Memcached;
 # ABSTRACT: Dancer 2 session storage with Cache::Memcached
-our $VERSION = '0.003'; # VERSION
+# VERSION
+our $VERSION = '0.004';
 
 use Carp;
 use Moo;
@@ -15,6 +16,12 @@ use Dancer2::Core::Types;
 # Public attributes
 #--------------------------------------------------------------------------#
 
+#pod =attr memcached_servers (required)
+#pod
+#pod A comma-separated list of reachable memcached servers (can be either
+#pod address:port or socket paths).
+#pod
+#pod =cut
 
 has memcached_servers => (
     is       => 'ro',
@@ -72,6 +79,12 @@ sub _sessions {
     return [];
 }
 
+sub _change_id {
+    my ( $self, $old_id, $new_id ) = @_;
+    $self->_flush( $new_id, $self->_retrieve( $old_id ) );
+    $self->_destroy( $old_id );
+}
+
 1;
 
 
@@ -81,7 +94,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -89,7 +102,7 @@ Dancer2::Session::Memcached - Dancer 2 session storage with Cache::Memcached
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -122,7 +135,7 @@ address:port or socket paths).
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/dancer2-session-memcached/issues>.
+at L<https://github.com/PerlDancer/dancer2-session-memcached/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -130,14 +143,30 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/dancer2-session-memcached>
+L<https://github.com/PerlDancer/dancer2-session-memcached>
 
-  git clone git://github.com/dagolden/dancer2-session-memcached.git
+  git clone https://github.com/PerlDancer/dancer2-session-memcached.git
 
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Peter Mottram Yanick Champoux
+
+=over 4
+
+=item *
+
+Peter Mottram <peter@sysnix.com>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
